@@ -1024,7 +1024,7 @@ class DebyeModel(Model):
                 ))
             f.write('\n')
 
-        print("\nFit information has been written to {}".format(
+        print("\nFit information has been written to {}\n".format(
             file_name
         ))
 
@@ -1256,7 +1256,7 @@ class GeneralisedDebyeModel(Model):
                 ))
             f.write('\n')
 
-        print("\nFit information has been written to {}".format(
+        print("\nFit information has been written to {}\mn".format(
             file_name
         ))
 
@@ -1491,7 +1491,7 @@ class TwoMaximaModel(Model):
                 ))
             f.write('\n')
 
-        print("\nFit information has been written to {}".format(
+        print("\nFit information has been written to {}\n".format(
             file_name
         ))
 
