@@ -198,16 +198,26 @@ def ac_mode_func(args):
     # the AC data.
     for models, experiments, dc_field in zip(all_models_sep, all_experiments_sep, unique_dc_fields): # noqa
 
+        base_filename = 'ac_model_{}_1sigma_{:.5f}Oe'.format(
+            models[0].NAME.replace(" ", "_"),
+            dc_field
+        )
+        base_filename = os.path.join(user_cfg.results_dir, base_filename)
+        fit_filename = '{}_params.out'.format(base_filename)
+
         print()
         print(
-            '   Part II: Fit the relaxation rate temperature dependence.\n'
+            '   Part II: Fit the relaxation rate temperature dependence.',
+            'at {} Oe\n'.format(dc_field)
         )
 
+
         if np.sum([model.fit_status for model in models]) <= 2:
             print(
                 '    ***Warning***:\n    Not enough data points to',
-                ' fit the relaxation profile.'
-            )
+                'fit the relaxation profile'
+            )   
+            continue
 
         if isinstance(models[0], ac.TwoMaximaModel):
             print('\n    ***Warning***:\n')
@@ -225,10 +235,10 @@ def ac_mode_func(args):
 
         # Instantiate the Relaxation_Profile class.
         rxp = relax.Relaxation_profile(
-                verbose=args.verbose,
-                sigma=args.sigma,
-                exe_mode='ac',
-                results_dir=user_cfg.results_dir
+            verbose=args.verbose,
+            sigma=args.sigma,
+            exe_mode='ac',
+            results_dir=user_cfg.results_dir
         )
 
         # Read-in the rates.
@@ -238,11 +248,9 @@ def ac_mode_func(args):
             AC_model=models[0].NAME,
             sigma=args.sigma
         )
-        if len(tau) == 1:
-            continue
 
         relax.select_model_rates(
-            rxp, temperature, 1./tau, 0., _process='tau_vs_T'
+            rxp, temperature, 1./tau, dc_field, _process='tau_vs_T', zf_options=True
         )
     return
 
